<?php

/**
 * Theme functions file
 *
 * Contains all of the Theme's setup functions, custom functions,
 * custom hooks and Theme settings.
 */

/**
 * Forprofit only works in WordPress 4.7 or later.
 */
if (version_compare($GLOBALS['wp_version'], '4.7', '<')) {
    require get_template_directory() . '/inc/back-compat.php';
    return;
}

/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * @since  1.0.0
 */
function forprofit_theme_setup() {

    // Make the theme available for translation.
    load_theme_textdomain('forprofit', get_template_directory() . '/languages');

    // Add RSS feed links to <head> for posts and comments.
    add_theme_support('automatic-feed-links');

    /*
	 * Let WordPress manage the document title.
	 * By adding theme support, we declare that this theme does not use a
	 * hard-coded <title> tag in the document head, and expect WordPress to
	 * provide it for us.
	 */
    add_theme_support('title-tag');

    // Enable support for Post Thumbnails.
    add_theme_support('post-thumbnails');

    // Declare image sizes.
    add_image_size('forprofit-featured-image', 2000, 950, true);
    add_image_size('forprofit-post-featured-image', 760, 450, true);
    add_image_size('forprofit-archive-featured-image', 526, 480, true);
    add_image_size('forprofit-posts-in-grid', 720, 460, true);

    // Register custom navigation menu.
    register_nav_menus(
        array(
            'primary'  => esc_html__('Primary Location', 'forprofit'),
            'footer'   => esc_html__('Footer Location', 'forprofit')
        )
    );

    /*
	* Switch default core markup for search form, comment form, and comments
	* to output valid HTML5.
	*/
    add_theme_support(
        'html5',
        array(
            'search-form',
            'comment-form',
            'comment-list',
            'gallery',
            'caption',
            'style',
            'script',
        )
    );

    /*
	 * Enable support for Post Formats.
	 * See: http://codex.wordpress.org/Post_Formats
	 */
    // add_theme_support('post-formats', array(
    //     'audio', 'image', 'gallery', 'video'
    // ));

    // Setup the WordPress core custom background feature.
    add_theme_support('custom-background', apply_filters('forprofit_custom_background_args', array(
        'default-color' => 'f5f5f5'
    )));

    // Enable support for Custom Logo
    add_theme_support('custom-logo', array(
        'height'      => 50,
        'width'       => 200,
        'flex-width' => true,
    ));

    // Enable theme-layouts extensions.
    add_theme_support(
        'theme-layouts',
        array(
            '1c'   => esc_html__('1 Column Wide (Full Width)', 'forprofit'),
            '1c-n' => esc_html__('1 Column Narrow (Full Width)', 'forprofit'),
            '2c-l' => esc_html__('2 Columns: Content / Sidebar', 'forprofit'),
            '2c-r' => esc_html__('2 Columns: Sidebar / Content', 'forprofit')
        ),
        array('customize' => false, 'default' => '2c-l')
    );

    // Indicate widget sidebars can use selective refresh in the Customizer.
    add_theme_support('customize-selective-refresh-widgets');

    // Adding support for core block visual styles.
    add_theme_support('wp-block-styles');

    // Add support for editor styles.
    add_theme_support('editor-styles');

    // Enqueue editor styles.
    add_editor_style('style-editor.css');

    // Add support for responsive embeds.
    add_theme_support('responsive-embeds');
}
add_action('after_setup_theme', 'forprofit_theme_setup');

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function forprofit_content_width() {
    // This variable is intended to be overruled from themes.
    // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
    // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
    $GLOBALS['content_width'] = apply_filters('forprofit_content_width', 760);
}
add_action('after_setup_theme', 'forprofit_content_width', 0);

/**
 * Set new content width if user uses 1 column layout.
 */
function forprofit_secondary_content_width() {
    if (in_array(get_theme_mod('theme_layout'), array('1c'))) {
        $GLOBALS['content_width'] = 1160;
    }
}
add_action('template_redirect', 'forprofit_secondary_content_width');

/**
 * Enqueue scripts and styles.
 */
function forprofit_enqueue() {

    $theme_version = wp_get_theme()->get('Version');

    // Fonts
    wp_enqueue_style('forprofit-fonts', forprofit_fonts_url());

    // 3rd party styles
    wp_enqueue_style('forprofit-fontawesome', get_template_directory_uri() . '/assets/css/font-awesome.min.css', array(), $theme_version);
    wp_enqueue_style('forprofit-magnific', get_template_directory_uri() . '/assets/css/magnific-popup.css', array(), $theme_version);
    wp_enqueue_style('forprofit-owlcarousel', get_template_directory_uri() . '/assets/css/owl.carousel.css', array(), $theme_version);
    wp_enqueue_style('forprofit-owlcarousel-theme', get_template_directory_uri() . '/assets/css/owl.theme.default.css', array(), $theme_version);
    wp_enqueue_style('forprofit-slicknav', get_template_directory_uri() . '/assets/css/slicknav.css', array(), $theme_version);

    // Main stylesheets
    wp_enqueue_style('forprofit-style', get_stylesheet_uri(), array(), null);
    wp_style_add_data('forprofit-style', 'rtl', 'replace');

    // Skins
    $color = get_theme_mod('forprofit_predefined_colors', 'default');
    wp_enqueue_style('forprofit-color', get_template_directory_uri() . '/assets/css/colors/' . $color . '.css', array(), null);

    // 3rd Party scripts
    wp_enqueue_script('forprofit-magnific', get_theme_file_uri('/assets/js/jquery.magnific-popup.js'), array('jquery'), $theme_version, true);
    wp_enqueue_script('forprofit-slicknav', get_theme_file_uri('/assets/js/jquery.slicknav.js'), array('jquery'), $theme_version, true);
    wp_enqueue_script('forprofit-owl', get_theme_file_uri('/assets/js/owl.carousel.js'), array('jquery'), $theme_version, true);
    wp_enqueue_script('forprofit-theia', get_theme_file_uri('/assets/js/theia-sticky-sidebar.js'), array('jquery'), $theme_version, true);

    // Main script
    wp_enqueue_script('forprofit-main-js', get_theme_file_uri('/assets/js/main.js'), array('jquery'), $theme_version, true);

    // Set up variables to pass to the custom script.
    global $wp_query;
    $localize_script = array(
        // Ajax load more
        'ajax_url'          => admin_url('admin-ajax.php'),
        'posts'             => json_encode($wp_query->query_vars),
        'current_page'      => get_query_var('paged') ? get_query_var('paged') : 1,
        'max_page'          => $wp_query->max_num_pages,
        'loading'           => esc_html__('Loading...', 'forprofit'),
        'btn_text'          => esc_html__('More Posts', 'forprofit'),
        'is_archive'        => (is_archive() || is_search()) ? true : false
    );

    // Pass custom variables to the script.
    wp_localize_script('forprofit-main-js', 'forprofit_variables', $localize_script);

    // js / no-js script.
    wp_add_inline_script('forprofit-main-js', "document.documentElement.className = document.documentElement.className.replace(/\bno-js\b/,'js');");

    // If child theme is active, load the stylesheet.
    if (is_child_theme()) {
        wp_enqueue_style('forprofit-child-style', get_stylesheet_uri(), array(), $theme_version);
    }

    // Load comment-reply script.
    if (is_singular() && comments_open() && get_option('thread_comments')) {
        wp_enqueue_script('comment-reply');
    }
}
add_action('wp_enqueue_scripts', 'forprofit_enqueue');

/**
 * Fix skip link focus in IE11.
 *
 * This does not enqueue the script because it is tiny and because it is only for IE11,
 * thus it does not warrant having an entire dedicated blocking script being loaded.
 *
 * @link https://git.io/vWdr2
 */
function forprofit_skip_link_focus_fix() {
?>
    <script>
        /(trident|msie)/i.test(navigator.userAgent) && document.getElementById && window.addEventListener && window.addEventListener("hashchange", function() {
            var t, e = location.hash.substring(1);
            /^[A-z0-9_-]+$/.test(e) && (t = document.getElementById(e)) && (/^(?:a|select|input|button|textarea)$/i.test(t.tagName) || (t.tabIndex = -1), t.focus())
        }, !1);
    </script>
<?php
}
add_action('wp_print_footer_scripts', 'forprofit_skip_link_focus_fix');

/**
 * Registers custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_widget
 */
function forprofit_widgets_init() {

    // Register Facebook widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-facebook.php';
    register_widget('Forprofit_Facebook_Widget');

    // Register recent posts thumbnail widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-recent.php';
    register_widget('Forprofit_Recent_Widget');

    // Register popular posts thumbnail widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-popular.php';
    register_widget('Forprofit_Popular_Widget');

    // Register random posts thumbnail widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-random.php';
    register_widget('Forprofit_Random_Widget');

    // Register twitter widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-twitter.php';
    register_widget('Forprofit_Twitter_Widget');

    // Register social widget.
    require trailingslashit(get_template_directory()) . 'inc/widgets/widget-social.php';
    register_widget('Forprofit_Social_Widget');
}
add_action('widgets_init', 'forprofit_widgets_init');

/**
 * Registers widget areas and custom widgets.
 *
 * @since 1.0.0
 * @link  http://codex.wordpress.org/Function_Reference/register_sidebar
 */
function forprofit_sidebars_init() {

    register_sidebar(
        array(
            'name'          => esc_html__('Primary Sidebar', 'forprofit'),
            'id'            => 'primary',
            'description'   => esc_html__('Main sidebar that appears on the right.', 'forprofit'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => esc_html__('Footer Sidebar 1', 'forprofit'),
            'id'            => 'footer-1',
            'description'   => esc_html__('Footer sidebar that appears at the bottom.', 'forprofit'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => esc_html__('Footer Sidebar 2', 'forprofit'),
            'id'            => 'footer-2',
            'description'   => esc_html__('Footer sidebar that appears at the bottom.', 'forprofit'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );

    register_sidebar(
        array(
            'name'          => esc_html__('Footer Sidebar 3', 'forprofit'),
            'id'            => 'footer-3',
            'description'   => esc_html__('Footer sidebar that appears at the bottom.', 'forprofit'),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget'  => '</aside>',
            'before_title'  => '<h3 class="widget-title">',
            'after_title'   => '</h3>',
        )
    );
}
add_action('widgets_init', 'forprofit_sidebars_init');

/**
 * Register Google fonts.
 *
 * @since  1.0.0
 * @return string
 */
function forprofit_fonts_url() {

    // Get the customizer data
    $body_font = get_theme_mod('forprofit_body_font', 'Poppins:ital,wght@0,400;0,500;0,700;1,400;1,700');
    $heading_font = get_theme_mod('forprofit_heading_font', 'Poppins:ital,wght@0,400;0,500;0,700;1,400;1,700');

    // Important variable
    $fonts_url = '';
    $fonts = array();

    if ($body_font) {
        $fonts[] = esc_attr(str_replace('+', ' ', $body_font));
    }

    if ($heading_font && ($body_font != $heading_font)) {
        $fonts[] = esc_attr(str_replace('+', ' ', $heading_font));
    }

    if ($fonts) {

        $query_args = array(
            'family' => urlencode(implode('|', $fonts)),
            'subset'  => urlencode('latin,latin-ext'),
            'display' => urlencode('swap'),
        );

        $fonts_url = add_query_arg($query_args, 'https://fonts.googleapis.com/css');
    }

    return esc_url_raw($fonts_url);
}

/**
 * Post views count
 */
function forprofit_post_views($id) {

    if (is_singular()) {

        $key   = 'post_views';
        $count = get_post_meta($id, $key, true);

        if ($count == '') {
            $count = 0;
            delete_post_meta($id, $key);
            add_post_meta($id, $key, '0');
        } else {
            $count++;
            update_post_meta($id, $key, $count);
        }
    }
}

if (!function_exists('forprofit_is_woocommerce_activated')) :
    /**
     * Check if WooCommerce is active
     */
    function forprofit_is_woocommerce_activated() {
        return class_exists('woocommerce') ? true : false;
    }
endif;

if (!function_exists('wp_body_open')) :
    /**
     * Shim for wp_body_open, ensuring backwards compatibility with versions of WordPress older than 5.2.
     */
    function wp_body_open() {
        do_action('wp_body_open');
    }
endif;

/**
 * Custom template tags for this theme.
 */
require trailingslashit(get_template_directory()) . 'inc/template-tags.php';

/**
 * Custom functions that act independently of the theme templates.
 */
require trailingslashit(get_template_directory()) . 'inc/extras.php';

/**
 * Require and recommended plugins list.
 */
require trailingslashit(get_template_directory()) . 'inc/plugins.php';

/**
 * Customizer.
 */
require trailingslashit(get_template_directory()) . 'inc/customizer.php';
require trailingslashit(get_template_directory()) . 'inc/customizer-sanitize.php';

/**
 * Page header.
 */
require trailingslashit(get_template_directory()) . 'inc/header.php';

/**
 * Signature.
 */
require trailingslashit(get_template_directory()) . 'inc/signature.php';

/**
 * We use some part of Hybrid Core to extends our themes.
 *
 * @link  http://themehybrid.com/hybrid-core Hybrid Core site.
 */
require trailingslashit(get_template_directory()) . 'inc/extensions/theme-layouts.php';
require trailingslashit(get_template_directory()) . 'inc/extensions/hybrid-media-grabber.php';

/**
 * Demo importer.
 */
require trailingslashit(get_template_directory()) . 'inc/demo/demo-importer.php';

/**
 * Load WooCommerce compatibility file.
 */
if (forprofit_is_woocommerce_activated()) {
    require trailingslashit(get_template_directory()) . 'inc/woocommerce.php';
}
