<?php

/**
 * WooCommerce compatibility and custom functions
 */

/**
 * WooCommerce setup function.
 *
 * @link https://docs.woocommerce.com/document/third-party-custom-theme-compatibility/
 * @link https://github.com/woocommerce/woocommerce/wiki/Enabling-product-gallery-features-(zoom,-swipe,-lightbox)-in-3.0.0
 * @return void
 */
function forprofit_woocommerce_setup() {
    add_theme_support('woocommerce', apply_filters('forprofit_wc_args', array(
        'product_grid'          => array(
            'default_columns' => 3,
            'default_rows'    => 4,
            'min_columns'     => 1,
            'max_columns'     => 6,
            'min_rows'        => 1
        )
    )));
    add_theme_support('wc-product-gallery-zoom');
    add_theme_support('wc-product-gallery-lightbox');
    add_theme_support('wc-product-gallery-slider');
}
add_action('after_setup_theme', 'forprofit_woocommerce_setup');

/**
 * WooCommerce specific scripts & stylesheets.
 *
 * @return void
 */
function forprofit_woocommerce_scripts() {

    wp_enqueue_style('forprofit-woocommerce', get_template_directory_uri() . '/woocommerce.css');

    $font_path   = WC()->plugin_url() . '/assets/fonts/';
    $inline_font = '@font-face {
			font-family: "star";
			src: url("' . $font_path . 'star.eot");
			src: url("' . $font_path . 'star.eot?#iefix") format("embedded-opentype"),
				url("' . $font_path . 'star.woff") format("woff"),
				url("' . $font_path . 'star.ttf") format("truetype"),
				url("' . $font_path . 'star.svg#star") format("svg");
			font-weight: normal;
			font-style: normal;
		}';

    wp_add_inline_style('forprofit-woocommerce', $inline_font);
}
add_action('wp_enqueue_scripts', 'forprofit_woocommerce_scripts');

/**
 * Disable the default WooCommerce stylesheet.
 *
 * Removing the default WooCommerce stylesheet and enqueing your own will
 * protect you during WooCommerce core updates.
 *
 * @link https://docs.woocommerce.com/document/disable-the-default-stylesheet/
 */
add_filter('woocommerce_enqueue_styles', '__return_empty_array');

/**
 * Disable the WooCommerce breadcrumbs.
 */
remove_action('woocommerce_before_main_content', 'woocommerce_breadcrumb', 20);

/**
 * Disable the Shop title.
 */
add_filter('woocommerce_show_page_title', '__return_false');

/**
 * Add 'woocommerce-active' class to the body tag.
 *
 * @param  array $classes CSS classes applied to the body tag.
 * @return array $classes modified to include 'woocommerce-active' class.
 */
function forprofit_woocommerce_active_body_class($classes) {
    $classes[] = 'woocommerce-active';

    return $classes;
}
add_filter('body_class', 'forprofit_woocommerce_active_body_class');

/**
 * Products per page.
 *
 * @return integer number of products.
 */
function forprofit_woocommerce_products_per_page() {
    return 12;
}
add_filter('loop_shop_per_page', 'forprofit_woocommerce_products_per_page');

/**
 * Product gallery thumnbail columns.
 *
 * @return integer number of columns.
 */
function forprofit_woocommerce_thumbnail_columns() {
    return 4;
}
add_filter('woocommerce_product_thumbnails_columns', 'forprofit_woocommerce_thumbnail_columns');

/**
 * Default loop columns on product archives.
 *
 * @return integer products per row.
 */
function forprofit_woocommerce_loop_columns() {
    return 3;
}
add_filter('loop_shop_columns', 'forprofit_woocommerce_loop_columns');

/**
 * Related Products Args.
 *
 * @param array $args related products args.
 * @return array $args related products args.
 */
function forprofit_woocommerce_related_products_args($args) {
    $defaults = array(
        'posts_per_page' => 3,
        'columns'        => 3,
    );

    $args = wp_parse_args($defaults, $args);

    return $args;
}
add_filter('woocommerce_output_related_products_args', 'forprofit_woocommerce_related_products_args');

if (!function_exists('forprofit_woocommerce_product_columns_wrapper')) {
    /**
     * Product columns wrapper.
     *
     * @return  void
     */
    function forprofit_woocommerce_product_columns_wrapper() {
        $columns = forprofit_woocommerce_loop_columns();
        echo '<div class="columns-' . absint($columns) . '">';
    }
}
add_action('woocommerce_before_shop_loop', 'forprofit_woocommerce_product_columns_wrapper', 40);

if (!function_exists('forprofit_woocommerce_product_columns_wrapper_close')) {
    /**
     * Product columns wrapper close.
     *
     * @return  void
     */
    function forprofit_woocommerce_product_columns_wrapper_close() {
        echo '</div>';
    }
}
add_action('woocommerce_after_shop_loop', 'forprofit_woocommerce_product_columns_wrapper_close', 40);

/**
 * Remove default WooCommerce wrapper.
 */
remove_action('woocommerce_before_main_content', 'woocommerce_output_content_wrapper', 10);
remove_action('woocommerce_after_main_content', 'woocommerce_output_content_wrapper_end', 10);

if (!function_exists('forprofit_woocommerce_wrapper_before')) {
    /**
     * Before Content.
     *
     * Wraps all WooCommerce content in wrappers which match the theme markup.
     *
     * @return void
     */
    function forprofit_woocommerce_wrapper_before() {
?>
        <div class="container">
            <div id="primary" class="content-area">
                <main id="main" class="site-main">
                <?php
            }
        }
        add_action('woocommerce_before_main_content', 'forprofit_woocommerce_wrapper_before');

        if (!function_exists('forprofit_woocommerce_wrapper_after')) {
            /**
             * After Content.
             *
             * Closes the wrapping divs.
             *
             * @return void
             */
            function forprofit_woocommerce_wrapper_after() {
                ?>
                </main><!-- #main -->
            </div><!-- #primary -->
        <?php
            }
        }
        add_action('woocommerce_after_main_content', 'forprofit_woocommerce_wrapper_after');

        if (!function_exists('forprofit_woocommerce_container_end')) {
            /**
             * Closes the container divs.
             *
             * @return void
             */
            function forprofit_woocommerce_container_end() {
        ?>
        </div><!-- .container -->
    <?php
            }
        }
        add_action('woocommerce_sidebar', 'forprofit_woocommerce_container_end');

        /**
         * Sample implementation of the WooCommerce Mini Cart.
         *
         * You can add the WooCommerce Mini Cart to header.php like so ...
         *
	<?php
		if ( function_exists( 'forprofit_woocommerce_header_cart' ) ) {
			forprofit_woocommerce_header_cart();
		}
	?>
         */

        if (!function_exists('forprofit_woocommerce_cart_link_fragment')) {
            /**
             * Cart Fragments.
             *
             * Ensure cart contents update when products are added to the cart via AJAX.
             *
             * @param array $fragments Fragments to refresh via AJAX.
             * @return array Fragments to refresh via AJAX.
             */
            function forprofit_woocommerce_cart_link_fragment($fragments) {
                ob_start();
                forprofit_woocommerce_cart_link();
                $fragments['a.cart-contents'] = ob_get_clean();

                return $fragments;
            }
        }
        add_filter('woocommerce_add_to_cart_fragments', 'forprofit_woocommerce_cart_link_fragment');

        if (!function_exists('forprofit_woocommerce_cart_link')) {
            /**
             * Cart Link.
             *
             * Displayed a link to the cart including the number of items present and the cart total.
             *
             * @return void
             */
            function forprofit_woocommerce_cart_link() {
    ?>
        <a class="cart-contents" href="<?php echo esc_url(wc_get_cart_url()); ?>" title="<?php esc_attr_e('View your shopping cart', 'forprofit'); ?>">
            <?php /* translators: number of items in the mini cart. */ ?>
            <span class="amount"><?php echo wp_kses_data(WC()->cart->get_cart_subtotal()); ?></span> <span class="count"><?php echo wp_kses_data(sprintf(_n('%d item', '%d items', WC()->cart->get_cart_contents_count(), 'forprofit'), WC()->cart->get_cart_contents_count())); ?></span>
        </a>
    <?php
            }
        }

        if (!function_exists('forprofit_woocommerce_header_cart')) {
            /**
             * Display Header Cart.
             *
             * @return void
             */
            function forprofit_woocommerce_header_cart() {
                if (is_cart()) {
                    $class = 'current-menu-item';
                } else {
                    $class = '';
                }
    ?>
        <ul id="site-header-cart" class="site-header-cart">
            <li class="<?php echo esc_attr($class); ?>">
                <?php forprofit_woocommerce_cart_link(); ?>
            </li>
            <li>
                <?php
                $instance = array(
                    'title' => '',
                );

                the_widget('WC_Widget_Cart', $instance);
                ?>
            </li>
        </ul>
    <?php
            }
        }

        if (!function_exists('forprofit_woocommerce_sorting_wrapper_before')) {
            /**
             * Before sorting.
             *
             * Wraps products sorting WooCommerce content.
             *
             * @return void
             */
            function forprofit_woocommerce_sorting_wrapper_before() {
    ?>
        <div class="products-sorting">
        <?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'forprofit_woocommerce_sorting_wrapper_before', 9);
        add_action('woocommerce_after_shop_loop', 'forprofit_woocommerce_sorting_wrapper_before', 9);

        if (!function_exists('forprofit_woocommerce_sorting_wrapper_after')) {
            /**
             * After sorting.
             *
             * Closes the products sorting wrapping divs.
             *
             * @return void
             */
            function forprofit_woocommerce_sorting_wrapper_after() {
        ?>
        </div><!-- .products-sorting -->
<?php
            }
        }
        add_action('woocommerce_before_shop_loop', 'forprofit_woocommerce_sorting_wrapper_after', 31);
        add_action('woocommerce_after_shop_loop', 'forprofit_woocommerce_sorting_wrapper_after', 31);

        /**
         * Extend archive title
         *
         * @since  1.0.0
         */
        function forprofit_extend_woocommerce_title($title) {
            if (is_shop()) {
                $title = 'Shop';
            }

            return $title;
        }
        add_filter('get_the_archive_title', 'forprofit_extend_woocommerce_title');
        add_filter('get_the_archive_title', 'forprofit_extend_woocommerce_title');

        /**
         * WooCommerce pages layout
         */
        function forprofit_woo_layouts($layout) {

            if (is_woocommerce()) {
                $post_layout = get_post_layout(get_queried_object_id());
                if ('default' === $post_layout) {
                    $layout = '2c-l';
                }
            }

            if (is_cart() || is_checkout()) {
                $post_layout = get_post_layout(get_queried_object_id());
                if ('default' === $post_layout) {
                    $layout = '1c';
                }
            }

            return $layout;
        }
        add_filter('theme_mod_theme_layout', 'forprofit_woo_layouts', 15);
